==> Mapster-1.5.6.1.zip: Mapster/Locale/deDE.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "deDE")
if not L then return end

L["Accuracy"] = "Genauigkeit"
L["Adjust the size of the Player Arrow on the Map for better visibility."] = "Justiere die Größe des Spielerpfeils auf der Karte für bessere Übersicht."
L["Alpha"] = "Alpha"
L["Battlegrounds"] = "Schlachtfelder"
L["BattleMap"] = "Gebietskarte"
L["Blobs & Panels"] = "Blobs & Panels"
L["Burning Crusade Instances"] = "Burning Crusade Instanzen"
L["Burning Crusade Raids"] = "Burning Crusade Raids"
L["Cataclysm Instances"] = "Cataclysm Instanzen"
L["Cataclysm Raids"] = "Cataclysm Raids"
L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "Ändere die Skalierung der Weltkarte wenn sie geöffnet weniger Platz in Anspruch nehmen soll."
L["Classic Instances"] = "Classic Instanzen"
L["Classic Raids"] = "Classic Raids"
L["Coordinates"] = "Koordinaten"
L["Cursor"] = "Cursor"
L["Debug"] = "Debug"
L["Disable Mouse"] = "Deaktiviere Maus"
L["Disable the mouse interactivity of the main map, eg. to change zones."] = "Deaktiviere die Mausinteraktion der Hauptkarte, z.B. um Zonen zu wechseln."
L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = "Deaktiviere die Mausinteraktion der Hauptkarte wenn minimiert, z.B. um Zonen zu wechseln."
-- L["EJ Icon Scale"] = "EJ Icon Scale"
L["Enable BattleMap"] = "Gebietskarte aktivieren"
L["Enable Coordinates"] = "Koordinaten aktivieren"
L["Enable FogClear"] = "FogClear aktivieren"
L["Enable Group Icons"] = "Gruppensymbole aktivieren"
L["Enable Instance Maps"] = "Instanzkarten aktivieren"
L["FogClear"] = "FogClear"
L["FogClear collects new Data in your own SavedVariables, but that data might get corrupted (or simply old) with a new patch. Reset the data if you see corruption in the world map."] = "FogClear sammelt neue Daten in deinen SavedVariables, aber diese Daten können korrumpiert (oder einfach alt) sein, z.B. mit einem neuen Patch. Setze die Daten zurück, wenn du Fehler in der Weltkarte entdeckst. "
L["Group Icons"] = "Gruppensymbole"
L["Hide Border"] = "Verstecke Rand"
L["Hide Completely"] = "Vollständig verstecken"
L["Hide Map Button"] = "Map Button verstecken"
-- L["Hide Quest Panels"] = "Hide Quest Panels"
L["Hide Textures"] = "Texturen verstecken"
L["Hide the borders of the big map."] = "Verstecke die Ränder der großen Karte."
L["Hide the borders of the minimized map."] = "Verstecke die Ränder der minimierten Karte."
L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = "Versteckt die umliegenden Texturen der Gebietskarte und belässt nur die Überlagerung der Karte."
L["Instance Maps"] = "Instanzkarten"
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "Mapster erlaubt die Kontrolle über verschiedene Aspekte deiner Weltkarte. Du kannst den Stil der Karte ändern, die Plugins die die Funktionalität der Weltkarte erweitern kontrollieren, und verschiedene Profile für alle deine Charaktere erstellen."
L["(Mini) Disable Mouse"] = "(Mini) Deaktiviere Maus"
L["(Mini) Hide Border"] = "(Mini) Verstecke Rand"
L["Minimized Alpha"] = "Alpha, wenn minimiert"
L["Minimized Scale"] = "Minimiere Maßstab"
L["Note: You need to reload your UI after reseting the data!"] = "Beachte: Du musst Deine UI neu laden, nachdem Du die Daten zurückgesetzt hast!"
L["Only WorldMap Blobs"] = "Nur WorldMap Blobs"
L["Overlay Color"] = "Overlay-Farbe"
L["Pandaria Instances"] = "Pandaria Instanzen"
L["Pandaria Raids"] = "Pandaria Raids"
L["Player"] = "Spieler"
L["PlayerArrow Scale"] = "Spielerpfeil skalieren"
L["POI Scale"] = "POI-Maßstab"
L["Reset FogClear Data"] = "FogClear zurücksetzen"
L["Scale"] = "Skalierung"
L["Scale of the big map."] = "Maßstab der großen Karte."
-- L["Scale of the Encounter Journal Icons on the Map."] = "Scale of the Encounter Journal Icons on the Map."
L["Scale of the minimized map."] = "Maßstab der minimierten Karte."
L["Scale of the POI Icons on the Map."] = "Maßstab der POI-Symbole auf der Karte."
L["Size on the Battle Map"] = "größe auf der Gebietskarte"
L["Size on the World Map"] = "größe auf der Weltkarte"
L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = "Das Gebietskarten Modul erlaubt Dir, die Schlachtfeld-Minimap anzupassen, indem es z.B. unnötige Texturen oder PvP Objekte entfernt."
L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "Das Koordinaten-Modul fügt die Anzeige deiner aktuellen Position hinzu, sowie die Koordinaten deines Mauszeigers auf der Weltkarte."
L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "Das FogClear-Modul entfernt den Nebel des Krieges auf der Weltkarte, womit alle bisher unentdeckten Gebiete automatisch aufgedeckt werden."
L["The Group Icons module allows you to resize the raid and party icons on the world map."] = "Das Gruppensymbol Modul erlaubt dir das vergrößern oder verkleinern der Spielersymbole auf der Welt- oder Gebietskarte"
L["The Instance Maps module allows you to view the Instance and Battleground Maps provided by the game without being in the instance yourself."] = "Das Instanzkarten Modul erlaubt Dir, vom Spiel mitgelieferte Instanzen und Schlachtfelder anzuschauen, ohne selbst in der Instanz zu sein."
L["The transparency of the big map."] = "Die Transparanz der großen Karte."
L["The transparency of the minimized map."] = "Die Transparanz der minimierten Karte."
L["Turn on debugging for the FogClear Module."] = "Schaltet Debugging für das FogClear Modul an."
L["Wrath Instances"] = "Wrath Instanzen"
L["Wrath Raids"] = "Wrath Raids"
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "Du kannst die Transparenz der Weltkarte ändern, so daß du weiterhin die Umgebung wahrnehmen kannst, während die Karte geöffnet."
L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "Du kannst die Genauigkeit der Koordinaten einstellen, zB wenn du sehr exakte Werte benötigst dann stelle den Wert auf 2."

==> Mapster-1.6.6.zip: Mapster/Locale/deDE.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "deDE")
if not L then return end

L["Accuracy"] = "Genauigkeit"
L["Adjust the size of the Player Arrow on the Map for better visibility."] = "Justiere die Größe des Spielerpfeils auf der Karte für bessere Übersicht."
L["Alpha"] = "Transparenz"
L["BattleMap"] = "Gebietskarte"
L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "Ändere die Skalierung der Weltkarte wenn sie geöffnet weniger Platz in Anspruch nehmen soll."
L["Coordinates"] = "Koordinaten"
L["Cursor"] = "Cursor"
L["Disable Mouse"] = "Deaktiviere Maus"
L["Disable the mouse interactivity of the main map, eg. to change zones."] = "Deaktiviere die Mausinteraktion der Hauptkarte, z.B. um Zonen zu wechseln."
L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = "Deaktiviere die Mausinteraktion der Hauptkarte wenn minimiert, z.B. um Zonen zu wechseln."
-- L["EJ Icon Scale"] = "EJ Icon Scale"
L["Enable BattleMap"] = "Gebietskarte aktivieren"
L["Enable Coordinates"] = "Koordinaten aktivieren"
L["Enable FogClear"] = "FogClear aktivieren"
L["Enable Group Icons"] = "Gruppensymbole aktivieren"
L["Faded Alpha"] = "Ausblendungstransparenz"
L["FogClear"] = "FogClear"
L["Font Size"] = "Schriftgröße"
-- L["Font Size on the minimized map."] = "Font Size on the minimized map."
L["Font Size on the normal map."] = "Schriftgröße auf der normalen Karte."
L["Group Icons"] = "Gruppensymbole"
L["Hide Border"] = "Verstecke Rand"
L["Hide Map Button"] = "Kartenbutton verstecken"
L["Hide Textures"] = "Texturen verstecken"
L["Hide the borders of the big map."] = "Verstecke die Ränder der großen Karte."
L["Hide the borders of the minimized map."] = "Verstecke die Ränder der minimierten Karte."
L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = "Versteckt die umliegenden Texturen der Gebietskarte und belässt nur die Überlagerung der Karte."
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "Mapster erlaubt die Kontrolle über verschiedene Aspekte deiner Weltkarte. Du kannst den Stil der Karte ändern, die Plugins die die Funktionalität der Weltkarte erweitern kontrollieren, und verschiedene Profile für alle deine Charaktere erstellen."
L["(Mini) Disable Mouse"] = "(Mini) Deaktiviere Maus"
-- L["(Mini) Font Size"] = "(Mini) Font Size"
L["(Mini) Hide Border"] = "(Mini) Verstecke Rand"
L["Minimized Alpha"] = "Alpha, wenn minimiert"
L["Minimized Scale"] = "Minimiere Maßstab"
L["Overlay Color"] = "Overlay-Farbe"
L["Player"] = "Spieler"
L["PlayerArrow Scale"] = "Spielerpfeil skalieren"
L["POI Scale"] = "POI-Maßstab"
L["Scale"] = "Skalierung"
L["Scale of the big map."] = "Maßstab der großen Karte."
-- L["Scale of the Encounter Journal Icons on the Map."] = "Scale of the Encounter Journal Icons on the Map."
L["Scale of the minimized map."] = "Maßstab der minimierten Karte."
L["Scale of the POI Icons on the Map."] = "Maßstab der POI-Symbole auf der Karte."
L["Size on the Battle Map"] = "Größe auf der Gebietskarte"
L["Size on the World Map"] = "Größe auf der Weltkarte"
L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = "Das Gebietskartenmodul erlaubt Dir, die Schlachtfeld-Minikarte anzupassen, indem es z.B. unnötige Texturen oder PvP-Objekte entfernt."
L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "Das Koordinaten-Modul fügt die Anzeige deiner aktuellen Position hinzu, sowie die Koordinaten deines Mauszeigers auf der Weltkarte."
L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "Das FogClear-Modul entfernt den Nebel des Krieges auf der Weltkarte, womit alle bisher unentdeckten Gebiete automatisch aufgedeckt werden."
L["The Group Icons module allows you to resize the raid and party icons on the world map."] = "Das Gruppensymbol Modul erlaubt dir das vergrößern oder verkleinern der Spielersymbole auf der Welt- oder Gebietskarte"
L["The map will fade out to the configured Fade Alpha level when you start moving."] = "Die Karte wird auf die eingestellte Ausblendungstransparenz gesetzt, wenn du beginnst, dich zu bewegen."
L["The transparency of the big map."] = "Die Transparanz der großen Karte."
L["The transparency of the map while you are moving and the map is faded."] = "Die Kartentransparenz während du dich bewegst und die Karte ausgeblendet wird."
L["The transparency of the minimized map."] = "Die Transparanz der minimierten Karte."
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "Du kannst die Transparenz der Weltkarte ändern, so daß du weiterhin die Umgebung wahrnehmen kannst, während die Karte geöffnet."
L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "Du kannst die Genauigkeit der Koordinaten einstellen, zB wenn du sehr exakte Werte benötigst dann stelle den Wert auf 2."
